# Offline TTS - Windows

ToolMate v0.2.42+ integrates [wsay](https://github.com/p-groarke/wsay) on Windows for text-to-speech feature.

# Download 'wsay.exe'

From version 0.2.61 of ToolMate AI, 'wsay.exe' is automatically downloaded, to '~\\toolmate' by default, when 'Wsay' is selected as the voice generation interface.

Current code install [v1.6.2 version of wsay](https://github.com/p-groarke/wsay/releases/tag/1.6.2).  You may manually install other versions. Read: https://github.com/p-groarke/wsay#install-instructions

# Setup

1. Select "change voice generation config" from action menu

2. Select "Wsay" from available options

3. Select a voice

4. Specify Speed

5. Select "toggle input audio" from action menu, to enable / disable reading input text

6. Select "toggle output audio" from action menu, to enable / disable reading output text